/*
 *  FILE    : MajordomoUser.java
 *  Ver     : 1.0      (Dec., `99)
 *  AUHTHOR : Sangyoon Oh
 *            soh@napc.syr.edu
 *
 */


import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import java.util.*;
import webwisdom.tango.config.*;
import org.w3c.dom.*;
import org.xml.sax.*;
import com.ibm.xml.parsers.DOMParser;

public class MajordomoUser {

    // ctor
    public MajordomoUser() throws IOException {
    
        // get dataModule Object    
        dm = new dataModule();
        
	// get filename from JFileChooser
        fileName = getFileName();
        
	// exit program if filename is not choosed
        if( fileName==null ) {
            JOptionPane.showMessageDialog( frame, "Please choose User Data File", 
            "File Name Error", JOptionPane.ERROR_MESSAGE );
            System.exit(1);
        }
        
	// open User data file
        try {
            dm.open("file", fileName, "user", "user");
            System.out.println("File Opened");
        }
        catch(Exception e) {
            System.out.println(e.toString());
        }
        
	// set-up GUI
        frame = new JFrame("MajorDomo User Tool");
        frame.setSize(350,230);        
        
        frame.addWindowListener( new WindowAdapter() {
            public void windowClosing( WindowEvent e ) {
		    System.exit( 0 );
		}
		    public void windowOpened(WindowEvent e) {}
            public void windowClosed(WindowEvent e) {}
            public void windowIconified(WindowEvent e) {}
            public void windowDeiconified(WindowEvent e) {}
            public void windowActivated(WindowEvent e) {}
            public void windowDeactivated(WindowEvent e) {}
		});
		
        // gui
        frame.getContentPane().setLayout(new BorderLayout());
        frame.getContentPane().add(loginPanel, BorderLayout.CENTER);   
        
        // ready 
        frame.pack();
        frame.setVisible(true);
    }
    
    // get File name using JFileChooser class
    public String getFileName() {
        String nfileName = null;
        JFileChooser chooser = new JFileChooser();
		chooser.setFileSelectionMode( JFileChooser.FILES_ONLY );
		
		if( lastDir != null ) {
			chooser.setCurrentDirectory( lastDir );
		}
		int result = chooser.showOpenDialog( frame );
		if( result == JFileChooser.APPROVE_OPTION ) {
			// store current directory for future use
			lastDir = chooser.getCurrentDirectory();
			nfileName = chooser.getSelectedFile().getPath();
		}
		return nfileName;
	}

    // show main panel after user authentication
    public void showMainPanel() {
        MainPanel mainPanel = new MainPanel(this);
        
	// get community list
        Enumeration ee = dm.getObjects("community");
        while( ee.hasMoreElements() ) {
            String commName = ee.nextElement().toString();
            try {
                boolean tf = mainPanel.member(dm.getValue("user", _userName, "e-mail"),
                        dm.getValue("community", commName, "userlist"), commName);
                if(commName.compareTo("system_manager")!=0) 
                    mainPanel.addCommunity( new Community(commName, new Boolean(tf)));
            }
            catch(IOException e1) {}
            catch(SAXException e2) {}
        }
        
        frame.getContentPane().removeAll();
        frame.getContentPane().add(mainPanel, BorderLayout.CENTER);
        frame.validate();
    }
    
    // main()
    public static void main(String[] args) {
        try {
            MajordomoUser mu;
            mu = new MajordomoUser();

        }
        catch(IOException e) {
            System.err.println("Can not create MajordomoUser class. " +e.getMessage());
        }
        
    }
    protected LoginPanel loginPanel = new LoginPanel(this);
    protected MainPanel mainPanel;
    protected JFrame frame;

    protected dataModule dm;
    protected String _userName = "default";
    protected String _passWord = "default"; 
    protected File lastDir = null;
    protected String fileName = null;
}
